<?php

namespace Params\Params\Policies;

use Litepie\User\Contracts\UserPolicy;
use Params\Params\Models\Params;

class ParamsPolicy
{

    /**
     * Determine if the given user can view the params.
     *
     * @param UserPolicy $user
     * @param Params $params
     *
     * @return bool
     */
    public function view(UserPolicy $user, Params $params)
    {
        if ($user->canDo('params.params.view') && $user->isAdmin()) {
            return true;
        }

        return $params->user_id == user_id() && $params->user_type == user_type();
    }

    /**
     * Determine if the given user can create a params.
     *
     * @param UserPolicy $user
     * @param Params $params
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('params.params.create');
    }

    /**
     * Determine if the given user can update the given params.
     *
     * @param UserPolicy $user
     * @param Params $params
     *
     * @return bool
     */
    public function update(UserPolicy $user, Params $params)
    {
        if ($user->canDo('params.params.edit') && $user->isAdmin()) {
            return true;
        }

        return $params->user_id == user_id() && $params->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given params.
     *
     * @param UserPolicy $user
     * @param Params $params
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Params $params)
    {
        return $params->user_id == user_id() && $params->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given params.
     *
     * @param UserPolicy $user
     * @param Params $params
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Params $params)
    {
        if ($user->canDo('params.params.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given params.
     *
     * @param UserPolicy $user
     * @param Params $params
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Params $params)
    {
        if ($user->canDo('params.params.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
